@@ -546,7 +546,7 @@ class CameraSource(Protocol):
     # end CameraInput
 
     async def get_prebuffering_state(self, container: Container) -> Optional[PrebufferState]: ...
-    async def probe_stream(self) -> Optional[ProbeStream]: ...
+    async def probe_stream(self, refresh: Optional[bool] = None) -> Optional[ProbeStream]: ...
 
 
 class CameraInternalSource(CameraSource, Protocol):
@@ -920,9 +920,11 @@ class DeviceManager(Protocol):
 
 
 class FfmpegArgs(TypedDict):
+    codec: str
     hwaccel: str
     hwaccelArgs: list[str]
     hwaccelFilters: list[str]
+    hwDeviceArgs: list[str]
     threads: str
 
 
@@ -935,7 +937,7 @@ class IceServer(TypedDict):
 @runtime_checkable
 class CoreManager(Protocol):
     async def get_ffmpeg_path(self) -> str: ...
-    async def get_hwaccel_info(self) -> FfmpegArgs: ...
+    async def get_hwaccel_info(self, target_codec: Union[Literal["h264"], Literal["h265"]]) -> FfmpegArgs: ...
     async def get_server_addresses(self) -> list[str]: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
 
